s6: the s6-fdholder-storec program
Keywords: s6 s6-fdholder fd-holding fd-holder fd storage unix socket activation

s6
Software
skarnet.org

# The `s6-fdholder-storec` program

`s6-fdholder-storec` talks to a fd-holding daemon on its open descriptors 6 and 7, and passes it a copy of its standard input.

## Interface

         s6-fdholder-storec [ -T fdtimeout ] [ -t timeout ] id

- s6-fdholder-storec expects to talk to a listening s6-fdholderd program on its descriptors 6 and 7.
- It attempts to pass a copy of its fd 0 (standard input) to s6-fdholderd, with identifier id.
- It then exits 0, or 1 if the server returned an error.

## Options

- `-T fdtimeout` : the descriptor is stored with an expiration time of fdtimeout milliseconds, which means the s6-fdholderd daemon will close and get rid of the descriptor after that time. By default, fdtimeout is 0, which means infinite - no expiration time.
- `-t timeout` : if the operation cannot be processed in timeout milliseconds, then fail with an error message. Communications with the server should be near-instant, so this option is only here to protect users against programming errors.

## Notes

- s6-fdholder-storec is the "internal" version of s6-fdholder-store. It simply expects to be run as a UCSPI client, i.e. talking to the server over descriptors 6 and 7, instead of connecting to the server itself.
- The error messages for the s6-fdholder suite are explained here.